@@ -69,9 +69,9 @@ def get_star_file_header(file_name):
 
 
 def write_star_file(path, boxes):
-    with open(path, "w") as boxfile:
+    with open(path, "w", newline='', encoding='utf-8') as boxfile:
         boxwriter = csv.writer(
-            boxfile, delimiter="\t", quotechar="|", quoting=csv.QUOTE_NONE
+            boxfile, delimiter="\t", quotechar="|", quoting=csv.QUOTE_NONE, lineterminator="\n",
         )
         boxwriter.writerow([])
         boxwriter.writerow(["data_"])
@@ -135,9 +135,9 @@ def read_star_filament_file(path, box_width, min_distance=0):
 
 
 def write_star_filemant_file(path, filaments):
-    with open(path, "w") as starfile:
+    with open(path, "w", newline='', encoding='utf-8') as starfile:
         starwriter = csv.writer(
-            starfile, delimiter="\t", quotechar="|", quoting=csv.QUOTE_NONE
+            starfile, delimiter="\t", quotechar="|", quoting=csv.QUOTE_NONE, lineterminator="\n",
         )
 
         starwriter.writerow(["data_"])
