@@ -34,6 +34,8 @@ class FilamentTracer:
         do_merging=True,
         box_distance=None,
         nosplit=False,
+        straightness_method=-1,
+        straightness_threshold=0.95
     ):
         """
         Traces filaments in the image using picked boxes as support points.
@@ -62,6 +64,11 @@ class FilamentTracer:
         self.do_merging = do_merging
         self.box_distance = box_distance
         self.nosplit = nosplit
+        if straightness_method == -1:
+            self.straightness_method = straightness_method
+        else:
+            self.straightness_method = straightness_method
+        self.straightness_threshold = straightness_threshold
 
     @property
     def boxes(self):
@@ -200,7 +207,7 @@ class FilamentTracer:
 
         # Make straight filaments
         if not self.nosplit:
-            filaments = split_filaments_by_straightness(filaments)
+            filaments = split_filaments_by_straightness(filaments, self.straightness_method, self.straightness_threshold)
 
         # NMS for filaments:
         filaments = nms_for_filaments(
@@ -308,7 +315,6 @@ class FilamentTracer:
                     result_tuble = (new_filament, sq_dist)
         return result_tuble
 
-
     def remove_parallel(self, filaments):
         """
         Remove parallel lines
@@ -700,9 +706,9 @@ def filter_filaments_by_num_boxes(filaments, minimum_number_boxes):
     return filtered_filaments
 
 
-def split_filaments_by_straightness(resamples_filaments, straightness_threshold=0.95):
+def split_filaments_by_straightness(resamples_filaments, straightness_method, straightness_threshold):
     """
-    Splits multiple filaments by straightness. See split_filament_by_straightness.
+    Splits multiple filaments by using a straightness method.
     :param resamples_filaments: List of filaments
     :param straightness_threshold: straightness threshold.
     :return: List of splitted filaments
@@ -710,8 +716,7 @@ def split_filaments_by_straightness(resamples_filaments, straightness_threshold=
     filamants_which_were_splitted = []
     new_fiament_segments = []
     for fil in resamples_filaments:
-        segments = split_filament_by_straightness(fil, straightness_threshold)
-
+        segments = split_filament_by_straightness_rec([fil], straightness_method, straightness_threshold)
         if len(segments) > 1:
             filamants_which_were_splitted.append(fil)
             new_fiament_segments.extend(segments)
@@ -723,6 +728,37 @@ def split_filaments_by_straightness(resamples_filaments, straightness_threshold=
         resamples_filaments.extend(new_fiament_segments)
     return resamples_filaments
 
+def split_filament_by_straightness_rec(filaments, straightness_method, straightness_threshold):
+
+    straight_line = [utils.BoundBox(x=0,y=0, w=0,h=0),
+                     utils.BoundBox(x=1,y=0, w=0,h=0),
+                     utils.BoundBox(x=2,y=0, w=0,h=0)]
+    non_straight_line = [utils.BoundBox(x=0,y=0, w=0,h=0),
+                         utils.BoundBox(x=1,y=1, w=0,h=0),
+                         utils.BoundBox(x=2,y=0, w=0,h=0)]
+
+    if straightness_method(straight_line) < straightness_method(non_straight_line):
+        a_is_more_straight = lambda a, b: a <= b
+    else:
+        a_is_more_straight = lambda a, b: a >= b
+
+    splitted_fils = []
+
+    for filament in filaments:
+        s = straightness_method(filament.boxes)
+        if not a_is_more_straight(s, straightness_threshold):
+            split_point = len(filament.boxes)//2
+            splitted_fils = [Filament(filament.boxes[split_point:]),Filament(filament.boxes[:split_point])]
+            splitted_fils.extend(split_filament_by_straightness_rec(splitted_fils,
+                                               straightness_method=straightness_method,
+                                               straightness_threshold=straightness_threshold))
+        else:
+            splitted_fils.append(filament)
+
+    return splitted_fils
+
+
+
 
 def split_filament_by_straightness(filament, straightness_threshold=0.95):
     """
@@ -731,27 +767,40 @@ def split_filament_by_straightness(filament, straightness_threshold=0.95):
     :param straightness_threshold:
     :return: List of splitted sub-filaments
     """
-
-    if _get_straightness(filament.boxes) >= straightness_threshold:
+    overall_staightness = _get_straightness(filament.boxes)
+    overall_rms = _get_rms(filament.boxes)
+    straightness_method = _get_rms
+    straightness_threshold = 20
+    a_is_more_straight = lambda a,b  : a<=b
+    print("overall:", overall_staightness, overall_rms)
+    if a_is_more_straight(straightness_method(filament.boxes), straightness_threshold):
         return [filament]
 
+
+
     list_splitted_filaments = [filament]
     last_list_size = 0
-
+    print("Do split")
     while len(list_splitted_filaments) > last_list_size:
 
         last_list_size = len(list_splitted_filaments)
         for fil in list_splitted_filaments:
-            if _get_straightness(fil.boxes) >= straightness_threshold:
+
+            if a_is_more_straight(straightness_method(fil.boxes),straightness_threshold):
                 continue
 
+
             max_straightness = -1
             max_straightness_index = -1
             for i in range(2, len(fil.boxes) - 2):
-                straightness_to_i = _get_straightness(fil.boxes[:i])
-                straightness_from_i = _get_straightness(fil.boxes[i:])
+                straightness_to_i = straightness_method(fil.boxes[:i])
+                straightness_from_i = straightness_method(fil.boxes[i:])
                 mean_straightness = (straightness_to_i + straightness_from_i) / 2
-                if mean_straightness > max_straightness:
+                print("Mean:", mean_straightness)
+                if max_straightness == -1:
+                    max_straightness = mean_straightness
+                    max_straightness_index = i
+                elif a_is_more_straight(mean_straightness,max_straightness):
                     max_straightness = mean_straightness
                     max_straightness_index = i
 
@@ -763,8 +812,34 @@ def split_filament_by_straightness(filament, straightness_threshold=0.95):
                 list_splitted_filaments.remove(fil)
                 list_splitted_filaments.append(new_fil_a)
                 list_splitted_filaments.append(new_fil_b)
+    print("Splitted into", len(list_splitted_filaments))
     return list_splitted_filaments
 
+def _get_rms(boxes):
+    def point_distance(lp_x1,lp_y1, lp_x2,lp_y2,p_x,p_y):
+        """
+        Measures distance point to line
+        """
+        dist = np.abs((lp_y2-lp_y1)*p_x - (lp_x2-lp_x1)*p_y + lp_x2*lp_y1 - lp_y2*lp_x1)/np.sqrt(np.power(lp_y2-lp_y1,2)+np.power(lp_x2-lp_x1,2))
+        return dist
+
+    if len(boxes) < 3:
+        return 0
+
+    sum_dist = 0
+    sumi = 0
+    for i in range(1, len(boxes)-1):
+        sumi = sumi + 1
+        sum_dist = sum_dist + np.power(
+            point_distance(boxes[0].x,
+                       boxes[0].y,
+                       boxes[-1].x,
+                       boxes[-1].y,
+                       boxes[i].x,
+                       boxes[i].y)
+            ,2)
+    rms = np.sqrt(sum_dist/(len(boxes)-2))
+    return rms
 
 def _get_straightness(boxes):
     """
@@ -885,7 +960,7 @@ def filament_direction(filament, num_last_boxes=5, from_head=False):
 
 def box_diff_direction_vector(box_a, box_b):
     norm_vec = (box_a.x - box_b.x, box_a.y - box_b.y)
-    norm_vec = norm_vec / np.linalg.norm(norm_vec)
+    norm_vec = norm_vec / (np.linalg.norm(norm_vec)+0.0001)
     return norm_vec
 
 
