@@ -120,6 +120,14 @@ class BoundBox:
 
         return self.score
 
+from enum import Enum
+class CryoloMode(Enum):
+
+    FIXED_SIZE=1
+    MIXED_ASPECT_RATIO=2
+    SQUARE=3
+    NON_SQUARE=4
+
 
 def getEquidistantBoxes(box1, box2, num_boxes):
     """
@@ -239,22 +247,23 @@ def resample_filament(filament, distance):
 
         return new_filament
     return None
+
 def get_cryolo_mode(size_distr, config_input_size):
     square_data_available = any([size[0] == size[1] for size in size_distr])
     non_square_data_available = any([size[0] != size[1] for size in size_distr])
 
     if type(config_input_size) == list:
-        return "FIXED-SIZE"
+        return CryoloMode.FIXED_SIZE
 
     if (square_data_available and non_square_data_available) or \
             (non_square_data_available and len(size_distr)>1):
-        return "MIXED-ASPECT-RATIO"
+        return CryoloMode.MIXED_ASPECT_RATIO
 
     if square_data_available and not non_square_data_available:
-        return "SQUARE"
+        return CryoloMode.SQUARE
 
     if not square_data_available and non_square_data_available and len(size_distr)==1:
-        return "NON-SQUARE"
+        return CryoloMode.NON_SQUARE
 
 def get_anchors(config, path_weights=None, image_sizes=None):
     '''
@@ -412,7 +421,7 @@ def normalize(image, margin_size=0):
     img_mean = np.mean(image[mask])
     img_std = np.std(image[mask])
 
-    image = (image - img_mean) / (3 * 2 * img_std)
+    image = (image - img_mean) / (3 * 2 * img_std+0.000001)
 
     return image
 
